pub struct Args {
pub root: String,
pub output: Option<String>,
pub copy_to_clipboard: bool,
pub include: Option<Vec<String>>,
pub exclude: Option<Vec<String>>,
pub checkout: Option<String>,
pub keep_blank_lines: bool,
pub no_ignore: bool,
}Expand description
Command line arguments for repocat.
Fields
root: StringGitHub repo URL or local folder path
output: Option<String>Output to file name, if provided. Else, output to stdout.
copy_to_clipboard: boolIf set, outputs using OSC 52 escape sequences to copy to clipboard directly.
include: Option<Vec<String>>Glob patterns to include files. Typically used to indicate file extensions to focus on. (e.g., “.rs,.toml”)
exclude: Option<Vec<String>>Glob patterns to exclude files (e.g., “.md,.txt”)
checkout: Option<String>A specific branch, tag, or commit to checkout after cloning e.g. –checkout “my-branch” or –checkout “abc123”
keep_blank_lines: boolIf set, blank lines will be preserved in the output
no_ignore: boolIf set, repocat will not ignore hidden or binary files. (In other words, it won’t use the default ignore rules from ripgrep.)